==> jc-1.4.0.tar.gz: soot/xml/XMLPrinter__24XMLLabel.h <==
// class soot.xml.XMLPrinter$XMLLabel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 99da81e7a31d45f5 soot_xml_XMLPrinter__24XMLLabel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_XMLPrinter__24XMLLabel_H_
#define _JC_soot_xml_XMLPrinter__24XMLLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_xml_XMLPrinter$object;

// Typedefs
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs	_jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs	_jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$refs	_jc_soot_xml_XMLPrinter__24XMLLabel$refs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs	_jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$object	_jc_soot_xml_XMLPrinter__24XMLLabel$object;

typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vmethods	_jc_soot_xml_XMLPrinter__24XMLLabel$vmethods;
typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtable	_jc_soot_xml_XMLPrinter__24XMLLabel$vtable;
typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtype	_jc_soot_xml_XMLPrinter__24XMLLabel$vtype;

// Constructors
extern void _jc_soot_xml_XMLPrinter__24XMLLabel$method$_init$b8a451f0c89646e0(_jc_env *, struct _jc_soot_xml_XMLPrinter__24XMLLabel$object *, struct _jc_soot_xml_XMLPrinter$object *, jlong, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vmethods {
};

// Vtable
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vmethods	soot_xml_XMLPrinter__24XMLLabel;
};

// Vtype
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtype {
	_jc_type			type;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs {
	struct _jc_java_lang_String$object	*methodName;
	struct _jc_java_lang_String$object	*label;
	struct _jc_soot_xml_XMLPrinter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$refs {
    _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs	soot_xml_XMLPrinter__24XMLLabel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs {
	jlong	id;
	jlong	stmtCount;
	jlong	stmtPercentage;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs	soot_xml_XMLPrinter__24XMLLabel;
};

// Object instance structure
struct _jc_soot_xml_XMLPrinter__24XMLLabel$object {
	_jc_soot_xml_XMLPrinter__24XMLLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vtype	*vtype;
	_jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_XMLPrinter__24XMLLabel$vtype _jc_soot_xml_XMLPrinter__24XMLLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_XMLPrinter__24XMLLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_XMLPrinter__24XMLLabel$class_object;

#endif	/* _JC_soot_xml_XMLPrinter__24XMLLabel_H_ */

==> jc-1.4.6.tar.gz: soot/xml/XMLPrinter__24XMLLabel.h <==
// class soot.xml.XMLPrinter$XMLLabel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 99da81e7a31d45f5 soot_xml_XMLPrinter__24XMLLabel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_XMLPrinter__24XMLLabel_H_
#define _JC_soot_xml_XMLPrinter__24XMLLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_xml_XMLPrinter$object;

// Typedefs
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs	_jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs	_jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$refs	_jc_soot_xml_XMLPrinter__24XMLLabel$refs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs	_jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs;
typedef struct _jc_soot_xml_XMLPrinter__24XMLLabel$object	_jc_soot_xml_XMLPrinter__24XMLLabel$object;

typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vmethods	_jc_soot_xml_XMLPrinter__24XMLLabel$vmethods;
typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtable	_jc_soot_xml_XMLPrinter__24XMLLabel$vtable;
typedef const struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtype	_jc_soot_xml_XMLPrinter__24XMLLabel$vtype;

// Constructors
extern void _jc_soot_xml_XMLPrinter__24XMLLabel$method$_init$b8a451f0c89646e0(_jc_env *, struct _jc_soot_xml_XMLPrinter__24XMLLabel$object *, struct _jc_soot_xml_XMLPrinter$object *, jlong, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vmethods {
};

// Vtable
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vmethods	soot_xml_XMLPrinter__24XMLLabel;
};

// Vtype
struct _jc_soot_xml_XMLPrinter__24XMLLabel$vtype {
	_jc_type			type;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs {
	struct _jc_java_lang_String$object	*methodName;
	struct _jc_java_lang_String$object	*label;
	struct _jc_soot_xml_XMLPrinter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$refs {
    _jc_soot_xml_XMLPrinter__24XMLLabel$sub_refs	soot_xml_XMLPrinter__24XMLLabel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs {
	jlong	id;
	jlong	stmtCount;
	jlong	stmtPercentage;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_XMLPrinter__24XMLLabel$sub_nonrefs	soot_xml_XMLPrinter__24XMLLabel;
};

// Object instance structure
struct _jc_soot_xml_XMLPrinter__24XMLLabel$object {
	_jc_soot_xml_XMLPrinter__24XMLLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_XMLPrinter__24XMLLabel$vtype	*vtype;
	_jc_soot_xml_XMLPrinter__24XMLLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_XMLPrinter__24XMLLabel$vtype _jc_soot_xml_XMLPrinter__24XMLLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_XMLPrinter__24XMLLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_XMLPrinter__24XMLLabel$class_object;

#endif	/* _JC_soot_xml_XMLPrinter__24XMLLabel_H_ */
